@@ -1,6 +1,6 @@
 import unittest
 
-from leeger.calculator.all_time_calculator.AWALAllTimeCalculator import AWALAllTimeCalculator
+from leeger.calculator.all_time_calculator import AWALAllTimeCalculator
 from leeger.enum.MatchupType import MatchupType
 from leeger.model.league.League import League
 from leeger.model.league.Matchup import Matchup
